@@ -32,8 +32,10 @@
 #define NCODES 100
 // symbol_code (p 604 new PostScript book): (1) define name, (2) Postscript
 // code, (3) symbol-font crossref code (used for estimage of symbol
-// size, by index_for_math_symbol() ... a bad idea, really).
-static char    *symbol_code[NCODES][3] = {
+// size, by index_for_math_symbol() ... a bad idea, really), and (4)
+// SVG code [broken; need to transcribe the codes from
+// http://www.w3.org/TR/html4/sgml/entities.html#h-24.3 one by one]
+static char *symbol_code[NCODES][4] = {
 	// name, code in Table E.11, p604 new ps book, char-equivalent}
 	// 
 	// Organization of list below is as in the tables in 
@@ -41,237 +43,227 @@ static char    *symbol_code[NCODES][3] = {
 	//
 	// Table 3.3 Greek Letters
 	// lowercase
-	{"alpha", "\\141", "a"},
-	{"beta", "\\142", "b"},
-	{"gamma", "\\147", "g"},
-	{"delta", "\\144", "d"},
-	{"epsilon", "\\145", "e"},
-// varepsilon
-	{"zeta", "\\172", "z"},
-	{"eta", "\\150", "h"},
-	{"theta", "\\161", "q"},
-	{"vartheta", "\\112", "q"},
-	{"iota", "\\151", "i"},
-	{"kappa", "\\153", "k"},
-	{"lambda", "\\154", "l"},
-	{"mu", "\\155", "m"},
-	{"nu", "\\156", "n"},
-	{"xi", "\\170", "x"},
-// o [not needed, really]
-	{"pi", "\\160", "p"},
-	{"varpi", "\\166", "p"},	// guess that size is same as pi
-	{"rho", "\\162", "r"},
-	{"sigma", "\\163", "s"},
-	{"varsigma", "\\126", "s"},
-	{"tau", "\\164", "t"},
-	{"upsilon", "\\165", "u"},
-	{"psi", "\\171", "y"},
-	{"chi", "\\143", "c"},
-	{"phi", "\\146", "f"},
-	{"varphi", "\\152", "f"},
-	{"omega", "\\167", "w"},
-//
-// Uppercase
-	{"Gamma", "\\107", "G"},
-	{"Delta", "\\104", "D"},
-	{"Theta", "\\121", "Q"},
-	{"Lambda", "\\114", "L"},
-	{"Xi", "\\130", "X"},
-	{"Pi", "\\120", "P"},
-	{"Sigma", "\\123", "S"},
-	{"Upsilon", "\\241", "Y"},	// guess that size is same as psi
-	{"Phi", "\\106", "F"},
-	{"Psi", "\\131", "Y"},
-	{"Omega", "\\127", "W"},
-// 
-// Table 3.4: Binary Operation Symbols
-	{"pm", "\\261", "+"}, // guess that size is same as +
-// mp
-	{"times", "\\264", "x"}, // guess that size is same as x
-	{"div", "\\270", "x"},	 // guess that size is same as x
-	{"ast", "\\052", "*"},
-// star
-	{"circ", "\\260", "."},	// guess that size is same as .
-	{"bullet", "\\267", "*"}, // guess that size is same as *
-	{"cdot", "\\327", ","},
-// cap
-// cup
-// uplus
-// sqcap
-// sqcup
-// vee
-	{"wedge", "\\331", "M"}, // guess that size is same as M
-// setminus
-// wr
-// diamond
-// bigtriangleup
-// bigtriangledown
-// triangleleft
-// triangleright
-// lhd
-// rhd
-// unlhd
-// unrhd
-	{"oplus", "\\305", "o"},
-// ominus
-	{"otimes", "\\304", "o"},
-// oslash
-// odot
-// bigcirc
-// dagger
-// ddagger
-// amalg
-//
-// Table 3.5: Relation Symbols
-	{"leq", "\\243", "<"}, // guess that size is same as <
-// prec
-// preceq
-// ll
-	{"subset", "\\314", "<"}, // guess that size is same as <
-	{"subseteq", "\\315", "<"}, // guess that size is same as <
-// sqsubset
-// sqsubseteq
-// MOVE 'in' to after 'infty'
-// vdash
-	{"geq", "\\263", ">"}, // guess that size is same as >
-// succ
-// succeq
-// gg
-	{"supset", "\\311", ">"}, // guess that size is same as >
-	{"supseteq", "\\312", ">"}, // guess that size is same as >
-// sqsupset
-// sqsupseteq    
-// ni
-// dashv
-	{"equiv", "\\272", "="}, // guess that size is same as =
-	{"sim", "\\176", "~"},
-// simeq
-// asymp
-	{"approx", "\\273", "~"}, // guess that size is same as ~
-	{"cong", "\\100", "="},	  // guess that size is same as =
-	{"neq", "\\271", "="},	  // guess that size is same as =
-// doteq
-	{"propto", "\\265", "~"}, // guess that size is same as ~    
-// models
-	{"perp", "\\136", "M"},
-// mid
-// parallel
-// bowtie
-// join
-// smile
-// frown
-// 
-// Table 3.6: Arrow Symbols
-	{"leftarrow", "\\254", "M"},
-	{"Leftarrow", "\\334", "M"},
-	{"rightarrow", "\\256", "M"},
-	{"Rightarrow", "\\336", "M"},
-	{"leftrightarrow", "\\253", "M"},
-	{"Leftrightarrow", "\\333", "M"},
-// mapsto
-// hookleftarrow
-// leftharpoonup
-// leftharpoondown
-// rightleftharpoons
-// longleftarrow
-// Longleftarrow
-// longrightarrow
-// Longrightarrow
-// longleftrightarrow
-// Longleftrightarrow
-// longmapsto
-// hookrightarrow
-// rightharpoonup
-// rightharpoon down
-// leadsto
-	{"uparrow", "\\255", "|"}, // guess that size is same as "|"
-	{"Uparrow", "\\335", "|"}, // guess that size is same as "|"
-	{"downarrow", "\\257", "|"}, // guess that size is same as "|"
-	{"Downarrow", "\\337", "|"}, // guess that size is same as "|"
-// updownarrow
-// Updownarrow
-// neararrow
-// searrow
-// swarrow
-// nwarrow
-//
-// Table 3.7: Miscellaneous Symbols
-	{"aleph", "\\300", "M"},
-// hbar
-// imath
-// jmath
-// ell
-	{"wp", "\\303", "M"},
-	{"Re", "\\302", "R"},		// guess that size is same as R
-	{"Im", "\\301", "M"},		// guess that size is same as M
-// mho
-	{"prime", "\\242", "'"},
-	{"emptyset", "\\306", "M"},
-	{"nabla", "\\321", "M"},	// guess that size is same as M
-	{"surd", "\\326", "M"},		// guess that size is same as M
-	{"sqrt", "\\326", "M"},		// not in this table, but what the heck
-// top
-	{"bot", "\\136", "M"},
-// |
-	{"angle", "\\320", "M"},
-	{"forall", "\\042", "M"},	// guess that size is same as M
-	{"exists", "\\044", "M"},	// guess that size is same as M
-	{"neg", "\\330", "M"},
-// flat
-// natural
-// sharp
-// backslash
-	{"partial", "\\266", "d"}, // guess that size is same as d
-	{"infty", "\\245", "M"},   // guess that size is same as M
-// Interpose 'int' and 'in' here to avoid clashes with 'infty'
-	{"int", "\\362", "M"}, // guess that size is same as M
-	{"in", "\\316", "<"},  // guess that size is same as <
-// Box
-// Diamond
-// triangle
-	{"clubsuit", "\\247", "M"},
-	{"diamondsuit", "\\340", "M"},
-// heartsuit
-	{"spadesuit", "\\252", "M"},
-//
-// Table 3.8 Variable-sized symbols
-	{"sum", "\\345", "M"}, // guess that size is same as M
-	{"prod", "\\325", "M"},	// guess that size is same as M
-// int -- moved up to avoid name clashes
-// oint
-// bigcap
-// bigcup
-// bigsqcup
-// bigvee
-// bigwedge
-// bigodot
-// bigotimes
-// bigoplus
-// biguplus
-//
-// Table 3.10
-// (
-// [
-// {
-	{"lfloor", "\\353", "M"},
-	{"lceil", "\\351", "M"},
-	{"langle", "\\341", "<"},
-// /
-// |
-// )
-// ]
-// }
-	{"rfloor", "\\373", "M"},
-	{"rceil", "\\371", "M"},
-	{"rangle", "\\361", ">"}
-// backslash SEE ABOVE
-// \|
-// uparrow SEE ABOVE
-// downarrow SEE ABOVE
-// updownarrow SEE ABOVE
-// Uparrow SEE ABOVE
-// Downarrow SEE ABOVE
-// Updownarrow SEE ABOVE
+	{(char *)"alpha", (char *)"\\141", (char *)"a", (char *)"&#945;"},
+	{(char *)"beta", (char *)"\\142", (char *)"b", (char *)"&#946;"},
+	{(char *)"gamma", (char *)"\\147", (char *)"g", (char *)"&#947;"},
+	{(char *)"delta", (char *)"\\144", (char *)"d", (char *)"&#948;"},
+	{(char *)"epsilon", (char *)"\\145", (char *)"e", (char *)"&#949;"},
+        // varepsilon
+	{(char *)"zeta", (char *)"\\172", (char *)"z", (char *)"&#952;"},
+	{(char *)"eta", (char *)"\\150", (char *)"h", (char *)"&#951;"},
+	{(char *)"theta", (char *)"\\161", (char *)"q", (char *)"&#952;"},
+	{(char *)"vartheta", (char *)"\\112", (char *)"q", (char *)"&#977;"},
+	{(char *)"iota", (char *)"\\151", (char *)"i", (char *)"&#9531;"},
+	{(char *)"kappa", (char *)"\\153", (char *)"k", (char *)"&#954;"},
+	{(char *)"lambda", (char *)"\\154", (char *)"l", (char *)"&#955;"},
+	{(char *)"mu", (char *)"\\155", (char *)"m", (char *)"&#956;"},
+	{(char *)"nu", (char *)"\\156", (char *)"n", (char *)"&#957;"},
+	{(char *)"xi", (char *)"\\170", (char *)"x", (char *)"&#958;"},
+        // o [not needed, really]
+	{(char *)"pi", (char *)"\\160", (char *)"p", (char *)"&#960;"},
+	{(char *)"varpi", (char *)"\\166", (char *)"p", (char *)"&#960;"},
+	{(char *)"rho", (char *)"\\162", (char *)"r", (char *)"&#961;"},
+	{(char *)"sigma", (char *)"\\163", (char *)"s", (char *)"&#963;"}, // or 962
+	{(char *)"varsigma", (char *)"\\126", (char *)"s", (char *)"&#962;"},
+	{(char *)"tau", (char *)"\\164", (char *)"t", (char *)"&#964;"},
+	{(char *)"upsilon", (char *)"\\165", (char *)"u", (char *)"&#965;"},
+	{(char *)"psi", (char *)"\\171", (char *)"y", (char *)"&#968;"},
+	{(char *)"chi", (char *)"\\143", (char *)"c", (char *)"&#967;"},
+	{(char *)"phi", (char *)"\\146", (char *)"f", (char *)"&#966;"},
+	{(char *)"varphi", (char *)"\\152", (char *)"f", (char *)"&#966;"}, //?
+	{(char *)"omega", (char *)"\\167", (char *)"w", (char *)"&#969;"},
+        //
+        // Uppercase
+	{(char *)"Gamma", (char *)"\\107", (char *)"G", (char *)"&#915;"},
+	{(char *)"Delta", (char *)"\\104", (char *)"D", (char *)"&#916;"},
+	{(char *)"Theta", (char *)"\\121", (char *)"Q", (char *)"&#920;"},
+	{(char *)"Lambda", (char *)"\\114", (char *)"L", (char *)"&#923;"},
+	{(char *)"Xi", (char *)"\\130", (char *)"X", (char *)"&#926;"},
+	{(char *)"Pi", (char *)"\\120", (char *)"P", (char *)"&#928;"},
+	{(char *)"Sigma", (char *)"\\123", (char *)"S", (char *)"&#931;"},
+	{(char *)"Upsilon", (char *)"\\241", (char *)"Y", (char *)"&#933;"},
+	{(char *)"Phi", (char *)"\\106", (char *)"F", (char *)"&#934;"},
+	{(char *)"Psi", (char *)"\\131", (char *)"Y", (char *)"&#936;"},
+	{(char *)"Omega", (char *)"\\127", (char *)"W", (char *)"&#937;"},
+        // Table 3.4: Binary Operation Symbols
+	{(char *)"pm", (char *)"\\261", (char *)"+", (char *)"&#177;"}, // guess that size is same as +
+        // mp
+	{(char *)"times", (char *)"\\264", (char *)"x", (char *)"&#215;"}, // guess that size is same as x
+	{(char *)"div", (char *)"\\270", (char *)"x", (char *)"&#247;"}, // guess that size is same as x
+	{(char *)"ast", (char *)"\\052", (char *)"*", (char *)"&#8727;"}, // star
+	{(char *)"circ", (char *)"\\260", (char *)".", (char *)"&#176;"},
+	{(char *)"bullet", (char *)"\\267", (char *)"*", (char *)"&#8226;"}, // guess that size is same as *
+	{(char *)"cdot", (char *)"\\327", (char *)",", (char *)"&#183;"}, // ? Georgian comma
+        // cap
+        // cup
+        // uplus
+        // sqcap
+        // sqcup
+        // vee
+	{(char *)"wedge", (char *)"\\331", (char *)"M", (char *)"&#8743;"}, // guess that size is same as M
+        // setminus
+        // wr
+        // diamond
+        // bigtriangleup
+        // bigtriangledown
+        // triangleleft
+        // triangleright
+        // lhd
+        // rhd
+        // unlhd
+        // unrhd
+	{(char *)"oplus", (char *)"\\305", (char *)"o", (char *)"&#8853;"},
+        // ominus
+	{(char *)"otimes", (char *)"\\304", (char *)"o", (char *)"&#8855;"},
+        // oslash
+        // odot
+        // bigcirc
+        // dagger
+        // ddagger
+        // amalg
+        //
+        // Table 3.5: Relation Symbols
+	{(char *)"leq", (char *)"\\243", (char *)"<", (char *)"&#8804;"}, // guess that size is same as <
+        // prec
+        // preceq
+        // ll
+	{(char *)"subset", (char *)"\\314", (char *)"<", (char *)"&#8834;"}, // guess that size is same as <
+	{(char *)"subseteq", (char *)"\\315", (char *)"<", (char *)"&#8838;"}, // guess that size is same as <
+        // sqsubset
+        // sqsubseteq
+        // MOVE 'in' to after 'infty'
+        // vdash
+	{(char *)"geq", (char *)"\\263", (char *)">", (char *)"&#8805;"},
+        // succ
+        // succeq
+        // gg
+	{(char *)"supset", (char *)"\\311", (char *)">", (char *)"&#8835;"},
+	{(char *)"supseteq", (char *)"\\312", (char *)">", (char *)"&#8839;"},
+        // sqsupset
+        // sqsupseteq    
+        // ni
+        // dashv
+	{(char *)"equiv", (char *)"\\272", (char *)"=", (char *)"&#8801;"},
+	{(char *)"sim", (char *)"\\176", (char *)"~", (char *)"&#8764;"},
+        // simeq
+        // asymp
+	{(char *)"approx", (char *)"\\273", (char *)"~", (char *)"&#8774;"}, // ?
+	{(char *)"cong", (char *)"\\100", (char *)"=", (char *)"&#8764;"}, // ?
+	{(char *)"neq", (char *)"\\271", (char *)"=", (char *)"&#8800;"},
+        // doteq
+	{(char *)"propto", (char *)"\\265", (char *)"~", (char *)"&#8733;"},
+        // models
+	{(char *)"perp", (char *)"\\136", (char *)"M", (char *)"&#8869;"},
+        // mid
+        // parallel
+        // bowtie
+        // join
+        // smile
+        // frown
+        // 
+        // Table 3.6: Arrow Symbols
+	{(char *)"leftarrow", (char *)"\\254", (char *)"M", (char *)"&#8592;"},
+	{(char *)"Leftarrow", (char *)"\\334", (char *)"M", (char *)"&#8656;"},
+	{(char *)"rightarrow", (char *)"\\256", (char *)"M", (char *)"&#8594;"},
+	{(char *)"Rightarrow", (char *)"\\336", (char *)"M", (char *)"&#8658;"},
+	{(char *)"leftrightarrow", (char *)"\\253", (char *)"M", (char *)"&#8596;"},
+	{(char *)"Leftrightarrow", (char *)"\\333", (char *)"M", (char *)"&#8660;"},
+        // mapsto
+        // hookleftarrow
+        // leftharpoonup
+        // leftharpoondown
+        // rightleftharpoons
+        // longleftarrow
+        // Longleftarrow
+        // longrightarrow
+        // Longrightarrow
+        // longleftrightarrow
+        // Longleftrightarrow
+        // longmapsto
+        // hookrightarrow
+        // rightharpoonup
+        // rightharpoon down
+        // leadsto
+	{(char *)"uparrow", (char *)"\\255", (char *)"|", (char *)"&#8593;"},
+	{(char *)"Uparrow", (char *)"\\335", (char *)"|", (char *)"&#8657;"},
+	{(char *)"downarrow", (char *)"\\257", (char *)"|", (char *)"&#8595;"},
+	{(char *)"Downarrow", (char *)"\\337", (char *)"|", (char *)"&#8659;"},
+        // updownarrow
+        // Updownarrow
+        // neararrow
+        // searrow
+        // swarrow
+        // nwarrow
+        //
+        // Table 3.7: Miscellaneous Symbols
+	{(char *)"aleph", (char *)"\\300", (char *)"M", (char *)"&#8501;"}, // ?
+        // hbar
+        // imath
+        // jmath
+        // ell
+	{(char *)"wp", (char *)"\\303", (char *)"M", (char *)"&#;8476"}, // BUG: figure out what this is
+	{(char *)"Re", (char *)"\\302", (char *)"R", (char *)"&#;8476"},
+	{(char *)"Im", (char *)"\\301", (char *)"M", (char *)"&#8465;"},
+        // mho
+	{(char *)"prime", (char *)"\\242", (char *)"'", (char *)"&#8242;"},
+	{(char *)"emptyset", (char *)"\\306", (char *)"M", (char *)"&#;8709"},
+	{(char *)"nabla", (char *)"\\321", (char *)"M", (char *)"&#8711;"},
+	{(char *)"surd", (char *)"\\326", (char *)"M", (char *)"&#8730;"},
+	{(char *)"sqrt", (char *)"\\326", (char *)"M", (char *)"&#8730;"},
+        // top
+	{(char *)"bot", (char *)"\\136", (char *)"M", (char *)"&#;8730"}, // BUG: no idea what this is
+        // |
+	{(char *)"angle", (char *)"\\320", (char *)"M", (char *)"&#8736;"},
+	{(char *)"forall", (char *)"\\042", (char *)"M", (char *)"&#8704;"},
+	{(char *)"exists", (char *)"\\044", (char *)"M", (char *)"&#8707;"},
+	{(char *)"neg", (char *)"\\330", (char *)"M", (char *)"&#172;"},
+        // flat
+        // natural
+        // sharp
+        // backslash
+	{(char *)"partial", (char *)"\\266", (char *)"d", (char *)"&#8706;"},
+	{(char *)"infty", (char *)"\\245", (char *)"M", (char *)"&#8734;"},
+        // Interpose 'int' and 'in' here to avoid clashes with 'infty'
+	{(char *)"int", (char *)"\\362", (char *)"M", (char *)"&#8747;"},
+	{(char *)"in", (char *)"\\316", (char *)"<", (char *)"&#8712;"},
+        // Box
+        // Diamond
+        // triangle
+	{(char *)"clubsuit", (char *)"\\247", (char *)"M", (char *)"&#9827;"},
+	{(char *)"diamondsuit", (char *)"\\340", (char *)"M", (char *)"&#9830;"},
+        // heartsuit
+	{(char *)"spadesuit", (char *)"\\252", (char *)"M", (char *)"&#9829;"},
+        //
+        // Table 3.8 Variable-sized symbols
+	{(char *)"sum", (char *)"\\345", (char *)"M", (char *)"&#8721;"},
+	{(char *)"prod", (char *)"\\325", (char *)"M", (char *)"&#8719;"},
+        // int -- moved up to avoid name clashes
+        // oint
+        // bigcap
+        // bigcup
+        // bigsqcup
+        // bigvee
+        // bigwedge
+        // bigodot
+        // bigotimes
+        // bigoplus
+        // biguplus
+        //
+        // Table 3.10
+	{(char *)"lfloor", (char *)"\\353", (char *)"M", (char *)"&#8970;"},
+	{(char *)"lceil", (char *)"\\351", (char *)"M", (char *)"&#8968;"},
+	{(char *)"langle", (char *)"\\341", (char *)"<", (char *)"&#9001;"},
+	{(char *)"rfloor", (char *)"\\373", (char *)"M", (char *)"&#8971;"},
+	{(char *)"rceil", (char *)"\\371", (char *)"M", (char *)"&#8969;"},
+	{(char *)"rangle", (char *)"\\361", (char *)">", (char *)"&#9002;"}
+        // backslash SEE ABOVE
+        // \|
+        // uparrow SEE ABOVE
+        // downarrow SEE ABOVE
+        // updownarrow SEE ABOVE
+        // Uparrow SEE ABOVE
+        // Downarrow SEE ABOVE
+        // Updownarrow SEE ABOVE
 };
 double gr_current_descender(void);
 std::vector<std::string> part_string(const std::string &s)
@@ -302,7 +294,7 @@ std::vector<std::string> part_string(const std::string &s)
 	return parts;
 }
 
-char* gr_fontname_from_id(int id);
+const char* gr_fontname_from_id(int id);
 
 #define	default_fontID		gr_font_Helvetica
 #define default_encoding        font_encoding_isolatin1
@@ -352,8 +344,10 @@ extern bool     _grPathExists;
 extern bool     _grWritePS;
 
 static void     gr_drawstring(const char *s);
+static void     gr_drawchar_svg(char c, double xcm, double ycm, gr_fontID font_id);
+static void     gr_drawsymbol_svg(int index, double xcm, double ycm, gr_fontID font_id);
 static void     gr_drawstring_svg(const char *s, double xcm, double ycm, double angle);
-static int      index_for_math_symbol(const char *s);	// base routine
+//static int      index_for_math_symbol(const char *s);	// base routine
 static double   gr_charwidth_cm(int c, int font, double fontsize_pt);
 static void     gr_DrawChar(const char *c);
 static void     gr_setfont_fontsize(gr_fontID newID, bool force = false);
@@ -363,28 +357,28 @@ static void     MoveUp(void);
 static void     MoveUp_svg(double *xcm, double *ycm);
 static void     MoveDn_svg(double *xcm, double *ycm);
 static void     MoveHorizontally(double em_distance);
-static char    *symbol_in_math(const char *sPtr, int *inc);
+static int      symbol_in_math(const char *sPtr, int *inc);
 
-gr_font_info    font_list[] =
+gr_font_info font_list[] =
 {
-	{gr_font_Courier, "Courier"},
-	{gr_font_CourierOblique, "Courier-Oblique"},
-	{gr_font_CourierBold, "Courier-Bold"},
-	{gr_font_CourierBoldOblique, "Courier-BoldOblique"},
-	{gr_font_Helvetica, "Helvetica"},
-	{gr_font_HelveticaBold, "Helvetica-Bold"},
-	{gr_font_HelveticaOblique, "Helvetica-Oblique"},
-	{gr_font_PalatinoRoman, "Palatino-Roman"},
-	{gr_font_PalatinoItalic, "Palatino-Italic"},
-	{gr_font_PalatinoBold, "Palatino-Bold"},
-	{gr_font_PalatinoBoldItalic, "Palatino-BoldItalic"},
-	{gr_font_Symbol, "Symbol"},
-	{gr_font_TimesRoman, "Times-Roman"},
-	{gr_font_TimesItalic, "Times-Italic"},
-	{gr_font_TimesBold, "Times-Bold"},
-	{gr_font_TimesBoldItalic, "Times-BoldItalic"},
-	{gr_font_Century, "Century"},
-	{gr_font_end_of_list, ""}
+	{gr_font_Courier, (char *)"Courier"},
+	{gr_font_CourierOblique, (char *)"Courier-Oblique"},
+	{gr_font_CourierBold, (char *)"Courier-Bold"},
+	{gr_font_CourierBoldOblique, (char *)"Courier-BoldOblique"},
+	{gr_font_Helvetica, (char *)"Helvetica"},
+	{gr_font_HelveticaBold, (char *)"Helvetica-Bold"},
+	{gr_font_HelveticaOblique, (char *)"Helvetica-Oblique"},
+	{gr_font_PalatinoRoman, (char *)"Palatino-Roman"},
+	{gr_font_PalatinoItalic, (char *)"Palatino-Italic"},
+	{gr_font_PalatinoBold, (char *)"Palatino-Bold"},
+	{gr_font_PalatinoBoldItalic, (char *)"Palatino-BoldItalic"},
+	{gr_font_Symbol, (char *)"Symbol"},
+	{gr_font_TimesRoman, (char *)"Times-Roman"},
+	{gr_font_TimesItalic, (char *)"Times-Italic"},
+	{gr_font_TimesBold, (char *)"Times-Bold"},
+	{gr_font_TimesBoldItalic, (char *)"Times-BoldItalic"},
+	{gr_font_Century, (char *)"Century"},
+	{gr_font_end_of_list, (char *)""}
 };
 
 // Draw text at specified location.
@@ -409,7 +403,7 @@ gr_show_at(/*const*/ char *s, double xcm, double ycm, gr_textStyle style, double
 		 || ycm > OFFPAGE_TOP)) {
 		warning("Drawing text at a location that is offpage.");
 	}
-	char *fn_svg = NULL;
+	const char *fn_svg = NULL;
 	double r, g, b;
 	_griState.color_text().getRGB(&r, &g, &b);
 	switch (_output_file_type) {
@@ -703,9 +697,8 @@ gr_drawstring(const char *s)
 					MoveUp();
 				} else if (*s == '\\') {
 					// Math character to superscript
-					int             inc;
-					char *            insert;
-					insert = symbol_in_math(s, &inc);
+					int inc;
+					int symbol_index = symbol_in_math(s, &inc);
 					if (inc) {
 						gr_fontID       oldfontID = gr_currentfont();
 						pstack.push(Superscript);
@@ -716,7 +709,7 @@ gr_drawstring(const char *s)
 						STOP_OLD_TEXT;
 						gr_setfont(gr_font_Symbol);
 						if (_grWritePS) {
-							fprintf(_grPS, "(%s) sh\n", insert);
+							fprintf(_grPS, "(%s) sh\n", symbol_code[symbol_index][1]);
 							check_psfile();
 						}
 						gr_setfont(oldfontID);
@@ -778,11 +771,10 @@ gr_drawstring(const char *s)
 					MoveDown();
 				} else if (*s == '\\') {
 					// Math character to subscript
-					int             inc;
-					char *            insert;
-					insert = symbol_in_math(s, &inc);
-					if (inc) {
-						gr_fontID       oldfontID = gr_currentfont();
+                                        int inc;
+					int symbol_index = symbol_in_math(s, &inc);
+					if (symbol_index > -1) {
+						gr_fontID oldfontID = gr_currentfont();
 						pstack.push(Subscript);
 #ifdef DEBUG
 						printf("DEBUG(%s:%d) pushed subscript=%d onto stack to make length %d\n",__FILE__,__LINE__,Subscript, int(pstack.size()));
@@ -791,7 +783,7 @@ gr_drawstring(const char *s)
 						STOP_OLD_TEXT;
 						gr_setfont(gr_font_Symbol);
 						if (_grWritePS) {
-							fprintf(_grPS, "(%s) sh\n", insert);
+							fprintf(_grPS, "(%s) sh\n", symbol_code[symbol_index][1]);
 							check_psfile();
 						}
 						gr_setfont(oldfontID);
@@ -857,8 +849,6 @@ gr_drawstring(const char *s)
 			} else if (*s == '\\') {
 				// Substitute math symbol, unless it's
 				// an escaped string
-				int inc;
-				char *insert;
 				if (*(s + 1) == '$') {
 					slast = *s++;
 				} else if (*(s + 1) == ',') {
@@ -881,14 +871,15 @@ gr_drawstring(const char *s)
 					START_NEW_TEXT;
 					slast = *s++;
 				} else {
-					insert = symbol_in_math(s, &inc);
+                                        int inc;
+					int symbol_index = symbol_in_math(s, &inc);
 					if (inc) {
 						// math symbol in symbol font
 						gr_fontID oldfontID = gr_currentfont();
 						STOP_OLD_TEXT;
 						gr_setfont(gr_font_Symbol);
 						if (_grWritePS) {
-							fprintf(_grPS, "(%s) sh\n", insert);
+							fprintf(_grPS, "(%s) sh\n", symbol_code[symbol_index][1]);
 							check_psfile();
 						}
 						gr_setfont(oldfontID);
@@ -945,7 +936,7 @@ gr_drawstring(const char *s)
 	return;
 }
 
-char* gr_fontname_from_id(int id)
+const char* gr_fontname_from_id(int id)
 {
 	switch (id) {
 	case gr_font_Courier:            return("Courier");
@@ -972,11 +963,11 @@ char* gr_fontname_from_id(int id)
 	return("Times");
 }
 
-static void gr_drawchar_svg(char c, double *xcm, double *ycm, gr_fontID font_id)
+static void gr_drawchar_svg(char c, double xcm, double ycm, gr_fontID font_id)
 {
-	char st[2];
 	double size = gr_currentfontsize_pt();
-	char *font_style;
+	const char *font_style;
+        //printf("%s:%d | gr_drawchar_svg('%c', ...) decodes to '%c' font_id=.s\n", __FILE__, __LINE__, c, symbol_code[int(c)][1]);//, gr_fontID);
 	if (pstack.size() > 0)
 		size *= SuperSize;
 	if (isdigit(c) || font_id == gr_font_Symbol)
@@ -985,15 +976,16 @@ static void gr_drawchar_svg(char c, double *xcm, double *ycm, gr_fontID font_id)
 		font_style = "italic";
 	const char *fill = _griState.color_text().get_hexcolor().c_str();
 	double transparency = _griState.color_text().getT();
-	fprintf(_grSVG, "<g><text x=\"%.1f\" y=\"%.1f\" font-family=\"%s\" font-size=\"%.1f\" font-style=\"%s\" fill=\"%s\" opacity=\"%.2f\" style=\"fill:%s\">%c</text></g>\n",
-		(*xcm) * PT_PER_CM, 
-		/*gr_page_height_pt() -*/ -(*ycm) * PT_PER_CM,
-		gr_fontname_from_id(font_id), size, font_style,
-		fill,
-		1.0 - transparency,
-		fill,
-		c);
+        fprintf(_grSVG, "<g><text x=\"%.1f\" y=\"%.1f\" font-family=\"%s\" font-size=\"%.1f\" font-style=\"%s\" fill=\"%s\" opacity=\"%.2f\" style=\"fill:%s\">%c</text></g>\n",
+                xcm * PT_PER_CM, 
+                /*gr_page_height_pt() -*/ -ycm * PT_PER_CM,
+                gr_fontname_from_id(font_id), size, font_style,
+                fill,
+                1.0 - transparency,
+                fill,
+                c);
 	gr_setfont(font_id);
+	char st[2];
 	st[0] = c; 
 	st[1] = '\0';
 	double w, a, d;
@@ -1001,10 +993,50 @@ static void gr_drawchar_svg(char c, double *xcm, double *ycm, gr_fontID font_id)
 	gr_setfontsize_pt(size);
 	gr_stringwidth(st, &w, &a, &d); // BUG: NEED TO SET FONT FIRST
 	gr_setfontsize_pt(oldfontsize);
-#ifdef DEBUG
-	printf("'%s' has width %f cm\n", st, w);
-#endif
-	*xcm += w;
+	//*xcm += w;
+}
+static void gr_drawsymbol_svg(int index, double xcm, double ycm, gr_fontID font_id)
+{
+	double size = gr_currentfontsize_pt();
+	const char *font_style;
+        //printf("%s:%d | gr_drawchar_svg('%c', ...) decodes to '%c' font_id=.s\n", __FILE__, __LINE__, c, symbol_code[int(c)][1]);//, gr_fontID);
+	if (pstack.size() > 0)
+		size *= SuperSize;
+	if (font_id == gr_font_Symbol)
+		font_style = "normal";
+	else
+		font_style = "italic";
+	const char *fill = _griState.color_text().get_hexcolor().c_str();
+	double transparency = _griState.color_text().getT();
+        if (font_id == gr_font_Symbol) {
+                fprintf(_grSVG, "<g><text x=\"%.1f\" y=\"%.1f\" font-family=\"%s\" font-size=\"%.1f\" font-style=\"%s\" fill=\"%s\" opacity=\"%.2f\" style=\"fill:%s\">%s</text></g>\n",
+                        xcm * PT_PER_CM, 
+                        /*gr_page_height_pt() -*/ -ycm * PT_PER_CM,
+                        gr_fontname_from_id(font_id), size, font_style,
+                        fill,
+                        1.0 - transparency,
+                        fill,
+                        symbol_code[index][3]);
+        } else {
+                fprintf(_grSVG, "<g><text x=\"%.1f\" y=\"%.1f\" font-family=\"%s\" font-size=\"%.1f\" font-style=\"%s\" fill=\"%s\" opacity=\"%.2f\" style=\"fill:%s\">%s</text></g>\n",
+                        xcm * PT_PER_CM, 
+                        /*gr_page_height_pt() -*/ -ycm * PT_PER_CM,
+                        gr_fontname_from_id(font_id), size, font_style,
+                        fill,
+                        1.0 - transparency,
+                        fill,
+                        "?");
+        }
+	gr_setfont(font_id);
+	char st[2];
+	st[0] = 'm';            // guess at width
+	st[1] = '\0';
+	double w, a, d;
+	double oldfontsize = gr_currentfontsize_pt();
+	gr_setfontsize_pt(size);
+	gr_stringwidth(st, &w, &a, &d); // BUG: NEED TO SET FONT FIRST
+	gr_setfontsize_pt(oldfontsize);
+                                //*xcm += w; // BUG
 }
 static void
 gr_drawstring_svg(const char *s, double xcm, double ycm, double angle)
@@ -1096,26 +1128,24 @@ gr_drawstring_svg(const char *s, double xcm, double ycm, double angle)
 //			w = gr_thinspace_cm() / 1.0; // put a bit of space before math
 //			xxcm += w;
 			if (p[nc-1] == '$') nc--;
-			fprintf(_grSVG, "<g>\n");
+			fprintf(_grSVG, "<!-- math mode -->\n<g>\n");
 			for (ic = 1; ic < nc; ic++) {
 #ifdef DEBUG
 				printf(" -- %d [%c] --\n", ic, p[ic]);
 #endif
 				if (p[ic] == '\\') { // HEREHEREHERE
 					if (p[ic+1] == '\\') {
-						gr_drawchar_svg('\\', &xxcm, &yycm, original_font);
+						gr_drawsymbol_svg(-1, xxcm, yycm, original_font);
 						ic += 1;
 						continue;
 					}
-					char *insert;
 					int inc;
-					insert = symbol_in_math(p.c_str() + ic, &inc);
-					int symbol_letter = index_for_math_symbol(insert);
+					int symbol_index = symbol_in_math(p.c_str() + ic, &inc);
 					if (inc) {
-						gr_drawchar_svg(symbol_letter, &xxcm, &yycm, gr_font_Symbol);
+						gr_drawsymbol_svg(symbol_index, xxcm, yycm, gr_font_Symbol);
 						ic += inc;
 					} else {
-						gr_drawchar_svg('?', &xxcm, &yycm, gr_font_Symbol);
+						gr_drawstring_svg("?", xxcm, yycm, gr_font_Symbol);
 					}
 				} else if (p[ic] == '{') {
 					// ignore
@@ -1141,7 +1171,7 @@ gr_drawstring_svg(const char *s, double xcm, double ycm, double angle)
 					pstack.push(Subscript);
 					MoveDn_svg(&xxcm, &yycm);
 					if (p[ic+1] != '{') { // BUG: should check for symbol
-						gr_drawchar_svg(p[ic+1], &xxcm, &yycm, original_font);
+						gr_drawchar_svg(p[ic+1], xxcm, yycm, original_font);
 						MoveUp_svg(&xxcm, &yycm);
 						pstack.pop();
 					}
@@ -1151,14 +1181,14 @@ gr_drawstring_svg(const char *s, double xcm, double ycm, double angle)
 					pstack.push(Superscript);
 					MoveUp_svg(&xxcm, &yycm);
 					if (p[ic+1] != '{') { // BUG: should check for symbol
-						gr_drawchar_svg(p[ic+1], &xxcm, &yycm, original_font);
+						gr_drawchar_svg(p[ic+1], xxcm, yycm, original_font);
 						MoveDn_svg(&xxcm, &yycm);
 						pstack.pop();
 					}
 					ic++;
 					continue;
 				} else {
-					gr_drawchar_svg(p[ic], &xxcm, &yycm, original_font);
+					gr_drawchar_svg(p[ic], xxcm, yycm, original_font);
 				}
 			}
 			fprintf(_grSVG, "</g>\n");
@@ -1276,21 +1306,18 @@ gr_setfont_fontsize(gr_fontID newID, bool force)
 	warning("Ignoring request for unknown font.");
 }
 
-//here
-
-static char *symbol_in_math(const char *sPtr, int *inc)
+static int symbol_in_math(const char *sPtr, int *inc) // handle greek letter or symbol in math mode
 {
-	/* handle greek letter or symbol in math mode */
 	sPtr++;
 	*inc = 0;
 	for (int i = 0; i < NCODES; i++) {
 		int len = strlen(symbol_code[i][0]);
 		if (!strncmp(sPtr, symbol_code[i][0], len)) {
 			*inc = len;
-			return symbol_code[i][1];
+			return i;
 		}
 	}
-	return NULL;
+	return -1;
 }
 
 // Clear the position stack (doesn't STL do this??)
@@ -1556,8 +1583,6 @@ gr_stringwidth(const char *s, double *w, double *a, double *d)
 			else if (*s == '}')	// ignore groups
 				;		// EMPTY
 			else if (*s == '\\') {	// handle synonym
-				int             skip;
-				char *            ss;
 				// First catch thinspace commands
 				if (*(s + 1) == ',') {
 					// Thinspace = Mwidth/6
@@ -1568,12 +1593,13 @@ gr_stringwidth(const char *s, double *w, double *a, double *d)
 					*w -= gr_charwidth_cm((int)'M', CurrentFont.id, CurrentFont.size_pt) / 6.0;
 					s += 1;
 				} else {
-					ss = symbol_in_math(s, &skip); // NULL if can't find
-					if (ss != NULL) {
-						gr_fontID       oldfontID = CurrentFont.id;
-						int             C = index_for_math_symbol(ss);
-						s += skip;
-						*w += gr_charwidth_cm(C, gr_font_Symbol, CurrentFont.size_pt);
+                                        int inc;
+					int symbol_index = symbol_in_math(s, &inc);
+					if (symbol_index > -1) {
+						gr_fontID oldfontID = CurrentFont.id;
+						s += inc;
+                                                // *w += gr_charwidth_cm("m" symbol_code[symbol_index][1], gr_font_Symbol, CurrentFont.size_pt);
+                                                *w += gr_charwidth_cm('m', gr_font_Symbol, CurrentFont.size_pt); //  BUG
 						CurrentFont.id = oldfontID;
 					} else {
 						// it's not a known math symbol
@@ -1609,9 +1635,9 @@ gr_stringwidth(const char *s, double *w, double *a, double *d)
 	_grWritePS = oldWritePS;
 }
 
+#if 0
 // return index (for size-table) for a character (given as integer)
-static int
-index_for_math_symbol(const char *s)
+static int index_for_math_symbol(const char *s)
 {
 	//printf("index_for_math_symbol(%s)\n",s);
 	if (!s) return (int)'?';
@@ -1626,6 +1652,7 @@ index_for_math_symbol(const char *s)
 	//printf("index_for_math_symbol(%s) cannot find a match\n", s);
 	return (int) 'M';	// a guess, since we have no clue
 }
+#endif
 
 // Return thinspace (=1/6 of width of "M" in current font), in cm
 double
