@@ -147,7 +147,7 @@ initialize_imageMask()
 bool
 image_range_exists()
 {
-	return ((_image0 != 0.0 || _image255 != 0.0) ? true : false);
+	return _image0 != 0.0 || _image255 != 0.0;
 }
 
 #if 0
