@@ -167,99 +167,99 @@ RPN_FCN         rpn_fcn[RPN_FCN_CAPACITY];
 // Operators, with common (algebraic) ones first to speed lookup.
 RPN_DICT        rpn_dict[] =
 {
-	{"+", 1, ADD},
-	{"-", 1, SUBTRACT},
-	{".", 1, MULTIPLY},
-	{"*", 1, MULTIPLY},
-	{"/", 1, DIVIDE},
-	{"power", 5, POWER},
-	{"age", 3, AGE},
-	{"asin", 4, ASINE},
-	{"acos", 4, ACOSINE},
-	{"atan", 4, ATANGENT},
-	{"sin", 3, SINE},
-	{"cos", 3, COSINE},
-	{"tan", 3, TANGENT},
-	{"asinh", 5, ASINH},
-	{"acosh", 5, ACOSH},
-	{"atanh", 5, ATANH},
-	{"cosh", 4, COSH},
-	{"sinh", 4, SINH},
-	{"tanh", 4, TANH},
-	{"sqrt", 4, SQRT},
-	{"log", 3, LOG},
-	{"ln", 2, LN},
-	{"exp", 3, EXP},
-	{"exp10", 5, EXP10},
-	{"ceil", 4, CEIL},
-	{"dec2hex", 7, DEC2HEX}, // cf hex2dec
-	{"floor", 5, FLOOR},
-	{"hex2dec", 7, HEX2DEC}, // cf dec2hex
-	{"remainder", 9, REMAINDER},
-	{"abs", 3, ABS},
-	{"<", 1, LESS_THAN},
-	{"<=", 2, LESS_THAN_EQUAL},
-	{">", 1, GREATER_THAN},
-	{">=", 2, GREATER_THAN_EQUAL},
-	{"==", 2, EQUAL},
-	{"!=", 2, NOT_EQUAL},
-	{"&", 1, AND},
-	{"and", 3, AND},
-	{"|", 1, OR},
-	{"or", 2, OR},
-	{"!", 1, NOT},
-	{"not", 3, NOT},
-	{"cmtopt", 6, CMTOPT},
-	{"pttocm", 6, PTTOCM},
-	{"dup", 3, DUP},
-	{"pop", 3, POP},
-	{"exch", 4, EXCH},
-	{"roll_left",  9, ROLL_LEFT},
-	{"roll_right", 10, ROLL_RIGHT},
-	{"pstack", 6, PSTACK},
-	{"strcat", 6, STRCAT},
-	{"strlen", 6, STRLEN},
-	{"substr", 6, SUBSTR},
-	{"atof", 4, ATOF},
-	{"system", 6, SYSTEM},
-	{"sup", 3, SUP},
-	{"inf", 3, INF},
-	{"=", 1, ASSIGN},
-	{"xcmtouser", 9, XCMTOUSER},
-	{"xpttouser", 9, XPTTOUSER},
-	{"xycmtouser", 10, XYCMTOUSER},
-	{"xyusertocm", 10, XYUSERTOCM},
-	{"xusertocm", 9, XUSERTOCM},
-	{"xusertopt", 9, XUSERTOPT},
-	{"ycmtouser", 9, YCMTOUSER},
-	{"ypttouser", 9, YPTTOUSER},
-	{"yusertocm", 9, YUSERTOCM},
-	{"yusertopt", 9, YUSERTOPT},
-	{"area", 4, AREA},
-	{"@", 1, VAL},
-	{"min", 3, MIN},
-	{"max", 3, MAX},
-	{"median", 6, MEDIAN},
-	{"mean",     4, MEAN},
-	{"stddev",   6, STDDEV},
-	{"skewness", 8, SKEWNESS},
-	{"kurtosis", 8, KURTOSIS},
-	{"size", 4, SIZE},
-	{"directory_exists", 16, DIRECTORY_EXISTS},
-	{"file_exists", 11, FILE_EXISTS},
-	{"argc", 4, ARGC},
-	{"argv", 4, ARGV},
-	{"sed", 3, SED},
-	{"width", 5, STRINGWIDTH},
-	{"ascent", 6, STRINGASCENT},
-	{"descent", 7, STRINGDESCENT},
-	{"defined", 7, DEFINED},
-	{"ismissing", 9, ISMISSING},
-	{"interpolate", 11, INTERPOLATE},
-	{"rand", 4, RAND},
-	{"wordc", 5, WORDC},
-	{"wordv", 5, WORDV},
-	{NULL, 0, NOT_OPERATOR}
+	{(char *)"+", 1, ADD},
+	{(char *)"-", 1, SUBTRACT},
+	{(char *)".", 1, MULTIPLY},
+	{(char *)"*", 1, MULTIPLY},
+	{(char *)"/", 1, DIVIDE},
+	{(char *)"power", 5, POWER},
+	{(char *)"age", 3, AGE},
+	{(char *)"asin", 4, ASINE},
+	{(char *)"acos", 4, ACOSINE},
+	{(char *)"atan", 4, ATANGENT},
+	{(char *)"sin", 3, SINE},
+	{(char *)"cos", 3, COSINE},
+	{(char *)"tan", 3, TANGENT},
+	{(char *)"asinh", 5, ASINH},
+	{(char *)"acosh", 5, ACOSH},
+	{(char *)"atanh", 5, ATANH},
+	{(char *)"cosh", 4, COSH},
+	{(char *)"sinh", 4, SINH},
+	{(char *)"tanh", 4, TANH},
+	{(char *)"sqrt", 4, SQRT},
+	{(char *)"log", 3, LOG},
+	{(char *)"ln", 2, LN},
+	{(char *)"exp", 3, EXP},
+	{(char *)"exp10", 5, EXP10},
+	{(char *)"ceil", 4, CEIL},
+	{(char *)"dec2hex", 7, DEC2HEX}, // cf hex2dec
+	{(char *)"floor", 5, FLOOR},
+	{(char *)"hex2dec", 7, HEX2DEC}, // cf dec2hex
+	{(char *)"remainder", 9, REMAINDER},
+	{(char *)"abs", 3, ABS},
+	{(char *)"<", 1, LESS_THAN},
+	{(char *)"<=", 2, LESS_THAN_EQUAL},
+	{(char *)">", 1, GREATER_THAN},
+	{(char *)">=", 2, GREATER_THAN_EQUAL},
+	{(char *)"==", 2, EQUAL},
+	{(char *)"!=", 2, NOT_EQUAL},
+	{(char *)"&", 1, AND},
+	{(char *)"and", 3, AND},
+	{(char *)"|", 1, OR},
+	{(char *)"or", 2, OR},
+	{(char *)"!", 1, NOT},
+	{(char *)"not", 3, NOT},
+	{(char *)"cmtopt", 6, CMTOPT},
+	{(char *)"pttocm", 6, PTTOCM},
+	{(char *)"dup", 3, DUP},
+	{(char *)"pop", 3, POP},
+	{(char *)"exch", 4, EXCH},
+	{(char *)"roll_left",  9, ROLL_LEFT},
+	{(char *)"roll_right", 10, ROLL_RIGHT},
+	{(char *)"pstack", 6, PSTACK},
+	{(char *)"strcat", 6, STRCAT},
+	{(char *)"strlen", 6, STRLEN},
+	{(char *)"substr", 6, SUBSTR},
+	{(char *)"atof", 4, ATOF},
+	{(char *)"system", 6, SYSTEM},
+	{(char *)"sup", 3, SUP},
+	{(char *)"inf", 3, INF},
+	{(char *)"=", 1, ASSIGN},
+	{(char *)"xcmtouser", 9, XCMTOUSER},
+	{(char *)"xpttouser", 9, XPTTOUSER},
+	{(char *)"xycmtouser", 10, XYCMTOUSER},
+	{(char *)"xyusertocm", 10, XYUSERTOCM},
+	{(char *)"xusertocm", 9, XUSERTOCM},
+	{(char *)"xusertopt", 9, XUSERTOPT},
+	{(char *)"ycmtouser", 9, YCMTOUSER},
+	{(char *)"ypttouser", 9, YPTTOUSER},
+	{(char *)"yusertocm", 9, YUSERTOCM},
+	{(char *)"yusertopt", 9, YUSERTOPT},
+	{(char *)"area", 4, AREA},
+	{(char *)"@", 1, VAL},
+	{(char *)"min", 3, MIN},
+	{(char *)"max", 3, MAX},
+	{(char *)"median", 6, MEDIAN},
+	{(char *)"mean",     4, MEAN},
+	{(char *)"stddev",   6, STDDEV},
+	{(char *)"skewness", 8, SKEWNESS},
+	{(char *)"kurtosis", 8, KURTOSIS},
+	{(char *)"size", 4, SIZE},
+	{(char *)"directory_exists", 16, DIRECTORY_EXISTS},
+	{(char *)"file_exists", 11, FILE_EXISTS},
+	{(char *)"argc", 4, ARGC},
+	{(char *)"argv", 4, ARGV},
+	{(char *)"sed", 3, SED},
+	{(char *)"width", 5, STRINGWIDTH},
+	{(char *)"ascent", 6, STRINGASCENT},
+	{(char *)"descent", 7, STRINGDESCENT},
+	{(char *)"defined", 7, DEFINED},
+	{(char *)"ismissing", 9, ISMISSING},
+	{(char *)"interpolate", 11, INTERPOLATE},
+	{(char *)"rand", 4, RAND},
+	{(char *)"wordc", 5, WORDC},
+	{(char *)"wordv", 5, WORDV},
+	{(char *)NULL, 0, NOT_OPERATOR}
 };
 
 
@@ -1335,6 +1335,8 @@ do_operation(operator_name oper)
 			pipefile = (FILE *) popen(output_lines, "r");
 			if (!pipefile) {
 				err("Sorry, cannot do `system' in RPN; failed popen() call");
+				delete [] thisline;
+				delete [] output_lines;
 				return false;
 			}
 			strcpy(output_lines, "");
